Timings class

Constructors

Timings()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCodeCountry() Future<String>
getDateEn() Future<String>
getDateHijriDate() Future<String>
getDateHijriWeekDay() Future<String>
getRegionCity() Future<String>
getTimeAsr() Future<String>
getTimeDhuhr() Future<String>
getTimeFajr() Future<String>
getTimeIsha() Future<String>
getTimeMaghrib() Future<String>
getTimeSunrise() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited